<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sl">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Vtičnik %1 ni združljiv s sistemom.</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Izklopi</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Vklopi</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Odstrani</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth nastavitve</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Izklopi</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Vklopi</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth nastavitve</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 je povezan</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Povezovanje...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Izklopljen</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Dodaj razpored tipk</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Datum in čas</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12 urni čas</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24 urni čas</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Nastavitve časa</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>Ponedeljek</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Torek</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Sreda</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Četrtek</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Petek</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sobota</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Nedelja</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>ponedeljek</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>wednesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>thursday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>friday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>saturday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>sunday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1year%2month%3day</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Želite počisiti %1 predmetov?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Tega dejanja se ne da razveljaviti</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Neznana naprava</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Neznan prostor</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Odpri</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Odklopi vse</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Zaganjalnik</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation>Zapri varni način</translation>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation>Varni način sidrišča</translation>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation>Sidrišče deluje v varnem načinu. Izhod za pravilen prikaz</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Modni način</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Učinkovit način</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Vrh</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Dno</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Levo</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Desno</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Ohrani prikazano</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Ohrani skrito</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Pametno skrivanje</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Način</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Položaj</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>Velikost</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>Več zaslonov</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation type="unfinished"/>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mode</source>
        <translation>Način</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Top</source>
        <translation>Vrh</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Dno</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Levo</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Desno</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Položaj</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Keep shown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Smart hide</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Small</source>
        <translation>Majhno</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Veliko</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>Na zaslonu s kurzorjem</translation>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation>Zgolj na glavnem zaslonu</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Prikaz večopravilnosti</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Odveži</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Na plošči</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavitve</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Napajanje</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Nastavitve energijske porabe</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Zmogljivost %1 za %2 min</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Zmogljivost %1 za %2 ur in %3 min</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Polnjenje %1 bo končano čez %2 min</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Polnjenje %1 bo končano čez %2 ur in %3 min</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Zmogljivost %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Polnim %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Zmogljvost %1 ..</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Zmogljivost %1 - polno</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>Zasidraj</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Način</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Položaj</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Velikost</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Prikaži namizje</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Odveži</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Napajanje</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Zaustavitev sistema</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Mirovanje</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Spanje</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zakleni</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Izpis</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Preklopi račun</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Nastavitve energijske porabe</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Ponovni zagon</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Omogoči zvok</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Utišaj</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Nastavitve zvoka</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Glasnost %1</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Zvok</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Smeti</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Zavrzi - %1 datoteko</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Zavrzi - %1 datoteke</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>Premakni v koš</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Odpri</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Prazno</translation>
    </message>
</context>
</TS>